# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#

import pprint
import re  # noqa: F401

import six


class WhiteLabelingParams(object):
    """NOTE: This class is auto generated by the swagger code generator program.    
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_title': 'str',
        'custom_css': 'str',
        'enable_help_links': 'bool',
        'favicon': 'Favicon',
        'favicon_checksum': 'str',
        'help_link_base_url': 'str',
        'logo_image_checksum': 'str',
        'logo_image_height': 'int',
        'logo_image_url': 'str',
        'palette_settings': 'PaletteSettings',
        'platform_name': 'str',
        'platform_version': 'str',
        'show_name_version': 'bool',
        'white_labeling_enabled': 'bool'
    }

    attribute_map = {
        'app_title': 'appTitle',
        'custom_css': 'customCss',
        'enable_help_links': 'enableHelpLinks',
        'favicon': 'favicon',
        'favicon_checksum': 'faviconChecksum',
        'help_link_base_url': 'helpLinkBaseUrl',
        'logo_image_checksum': 'logoImageChecksum',
        'logo_image_height': 'logoImageHeight',
        'logo_image_url': 'logoImageUrl',
        'palette_settings': 'paletteSettings',
        'platform_name': 'platformName',
        'platform_version': 'platformVersion',
        'show_name_version': 'showNameVersion',
        'white_labeling_enabled': 'whiteLabelingEnabled'
    }

    def __init__(self, app_title=None, custom_css=None, enable_help_links=None, favicon=None, favicon_checksum=None, help_link_base_url=None, logo_image_checksum=None, logo_image_height=None, logo_image_url=None, palette_settings=None, platform_name=None, platform_version=None, show_name_version=None, white_labeling_enabled=None):  # noqa: E501
        """WhiteLabelingParams - a model defined in Swagger"""  # noqa: E501

        self._app_title = None
        self._custom_css = None
        self._enable_help_links = None
        self._favicon = None
        self._favicon_checksum = None
        self._help_link_base_url = None
        self._logo_image_checksum = None
        self._logo_image_height = None
        self._logo_image_url = None
        self._palette_settings = None
        self._platform_name = None
        self._platform_version = None
        self._show_name_version = None
        self._white_labeling_enabled = None
        self.discriminator = None

        if app_title is not None:
            self.app_title = app_title
        if custom_css is not None:
            self.custom_css = custom_css
        if enable_help_links is not None:
            self.enable_help_links = enable_help_links
        if favicon is not None:
            self.favicon = favicon
        if favicon_checksum is not None:
            self.favicon_checksum = favicon_checksum
        if help_link_base_url is not None:
            self.help_link_base_url = help_link_base_url
        if logo_image_checksum is not None:
            self.logo_image_checksum = logo_image_checksum
        if logo_image_height is not None:
            self.logo_image_height = logo_image_height
        if logo_image_url is not None:
            self.logo_image_url = logo_image_url
        if palette_settings is not None:
            self.palette_settings = palette_settings
        if platform_name is not None:
            self.platform_name = platform_name
        if platform_version is not None:
            self.platform_version = platform_version
        if show_name_version is not None:
            self.show_name_version = show_name_version
        if white_labeling_enabled is not None:
            self.white_labeling_enabled = white_labeling_enabled

    @property
    def app_title(self):
        """Gets the app_title of this WhiteLabelingParams.  # noqa: E501


        :return: The app_title of this WhiteLabelingParams.  # noqa: E501
        :rtype: str
        """
        return self._app_title

    @app_title.setter
    def app_title(self, app_title):
        """Sets the app_title of this WhiteLabelingParams.


        :param app_title: The app_title of this WhiteLabelingParams.  # noqa: E501
        :type: str
        """

        self._app_title = app_title

    @property
    def custom_css(self):
        """Gets the custom_css of this WhiteLabelingParams.  # noqa: E501


        :return: The custom_css of this WhiteLabelingParams.  # noqa: E501
        :rtype: str
        """
        return self._custom_css

    @custom_css.setter
    def custom_css(self, custom_css):
        """Sets the custom_css of this WhiteLabelingParams.


        :param custom_css: The custom_css of this WhiteLabelingParams.  # noqa: E501
        :type: str
        """

        self._custom_css = custom_css

    @property
    def enable_help_links(self):
        """Gets the enable_help_links of this WhiteLabelingParams.  # noqa: E501


        :return: The enable_help_links of this WhiteLabelingParams.  # noqa: E501
        :rtype: bool
        """
        return self._enable_help_links

    @enable_help_links.setter
    def enable_help_links(self, enable_help_links):
        """Sets the enable_help_links of this WhiteLabelingParams.


        :param enable_help_links: The enable_help_links of this WhiteLabelingParams.  # noqa: E501
        :type: bool
        """

        self._enable_help_links = enable_help_links

    @property
    def favicon(self):
        """Gets the favicon of this WhiteLabelingParams.  # noqa: E501


        :return: The favicon of this WhiteLabelingParams.  # noqa: E501
        :rtype: Favicon
        """
        return self._favicon

    @favicon.setter
    def favicon(self, favicon):
        """Sets the favicon of this WhiteLabelingParams.


        :param favicon: The favicon of this WhiteLabelingParams.  # noqa: E501
        :type: Favicon
        """

        self._favicon = favicon

    @property
    def favicon_checksum(self):
        """Gets the favicon_checksum of this WhiteLabelingParams.  # noqa: E501


        :return: The favicon_checksum of this WhiteLabelingParams.  # noqa: E501
        :rtype: str
        """
        return self._favicon_checksum

    @favicon_checksum.setter
    def favicon_checksum(self, favicon_checksum):
        """Sets the favicon_checksum of this WhiteLabelingParams.


        :param favicon_checksum: The favicon_checksum of this WhiteLabelingParams.  # noqa: E501
        :type: str
        """

        self._favicon_checksum = favicon_checksum

    @property
    def help_link_base_url(self):
        """Gets the help_link_base_url of this WhiteLabelingParams.  # noqa: E501


        :return: The help_link_base_url of this WhiteLabelingParams.  # noqa: E501
        :rtype: str
        """
        return self._help_link_base_url

    @help_link_base_url.setter
    def help_link_base_url(self, help_link_base_url):
        """Sets the help_link_base_url of this WhiteLabelingParams.


        :param help_link_base_url: The help_link_base_url of this WhiteLabelingParams.  # noqa: E501
        :type: str
        """

        self._help_link_base_url = help_link_base_url

    @property
    def logo_image_checksum(self):
        """Gets the logo_image_checksum of this WhiteLabelingParams.  # noqa: E501


        :return: The logo_image_checksum of this WhiteLabelingParams.  # noqa: E501
        :rtype: str
        """
        return self._logo_image_checksum

    @logo_image_checksum.setter
    def logo_image_checksum(self, logo_image_checksum):
        """Sets the logo_image_checksum of this WhiteLabelingParams.


        :param logo_image_checksum: The logo_image_checksum of this WhiteLabelingParams.  # noqa: E501
        :type: str
        """

        self._logo_image_checksum = logo_image_checksum

    @property
    def logo_image_height(self):
        """Gets the logo_image_height of this WhiteLabelingParams.  # noqa: E501


        :return: The logo_image_height of this WhiteLabelingParams.  # noqa: E501
        :rtype: int
        """
        return self._logo_image_height

    @logo_image_height.setter
    def logo_image_height(self, logo_image_height):
        """Sets the logo_image_height of this WhiteLabelingParams.


        :param logo_image_height: The logo_image_height of this WhiteLabelingParams.  # noqa: E501
        :type: int
        """

        self._logo_image_height = logo_image_height

    @property
    def logo_image_url(self):
        """Gets the logo_image_url of this WhiteLabelingParams.  # noqa: E501


        :return: The logo_image_url of this WhiteLabelingParams.  # noqa: E501
        :rtype: str
        """
        return self._logo_image_url

    @logo_image_url.setter
    def logo_image_url(self, logo_image_url):
        """Sets the logo_image_url of this WhiteLabelingParams.


        :param logo_image_url: The logo_image_url of this WhiteLabelingParams.  # noqa: E501
        :type: str
        """

        self._logo_image_url = logo_image_url

    @property
    def palette_settings(self):
        """Gets the palette_settings of this WhiteLabelingParams.  # noqa: E501


        :return: The palette_settings of this WhiteLabelingParams.  # noqa: E501
        :rtype: PaletteSettings
        """
        return self._palette_settings

    @palette_settings.setter
    def palette_settings(self, palette_settings):
        """Sets the palette_settings of this WhiteLabelingParams.


        :param palette_settings: The palette_settings of this WhiteLabelingParams.  # noqa: E501
        :type: PaletteSettings
        """

        self._palette_settings = palette_settings

    @property
    def platform_name(self):
        """Gets the platform_name of this WhiteLabelingParams.  # noqa: E501


        :return: The platform_name of this WhiteLabelingParams.  # noqa: E501
        :rtype: str
        """
        return self._platform_name

    @platform_name.setter
    def platform_name(self, platform_name):
        """Sets the platform_name of this WhiteLabelingParams.


        :param platform_name: The platform_name of this WhiteLabelingParams.  # noqa: E501
        :type: str
        """

        self._platform_name = platform_name

    @property
    def platform_version(self):
        """Gets the platform_version of this WhiteLabelingParams.  # noqa: E501


        :return: The platform_version of this WhiteLabelingParams.  # noqa: E501
        :rtype: str
        """
        return self._platform_version

    @platform_version.setter
    def platform_version(self, platform_version):
        """Sets the platform_version of this WhiteLabelingParams.


        :param platform_version: The platform_version of this WhiteLabelingParams.  # noqa: E501
        :type: str
        """

        self._platform_version = platform_version

    @property
    def show_name_version(self):
        """Gets the show_name_version of this WhiteLabelingParams.  # noqa: E501


        :return: The show_name_version of this WhiteLabelingParams.  # noqa: E501
        :rtype: bool
        """
        return self._show_name_version

    @show_name_version.setter
    def show_name_version(self, show_name_version):
        """Sets the show_name_version of this WhiteLabelingParams.


        :param show_name_version: The show_name_version of this WhiteLabelingParams.  # noqa: E501
        :type: bool
        """

        self._show_name_version = show_name_version

    @property
    def white_labeling_enabled(self):
        """Gets the white_labeling_enabled of this WhiteLabelingParams.  # noqa: E501


        :return: The white_labeling_enabled of this WhiteLabelingParams.  # noqa: E501
        :rtype: bool
        """
        return self._white_labeling_enabled

    @white_labeling_enabled.setter
    def white_labeling_enabled(self, white_labeling_enabled):
        """Sets the white_labeling_enabled of this WhiteLabelingParams.


        :param white_labeling_enabled: The white_labeling_enabled of this WhiteLabelingParams.  # noqa: E501
        :type: bool
        """

        self._white_labeling_enabled = white_labeling_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WhiteLabelingParams, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WhiteLabelingParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class RuleEngineControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def handle_rule_engine_request_using_post(self, request_body, **kwargs):  # noqa: E501
        """handleRuleEngineRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.handle_rule_engine_request_using_post(request_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str request_body: requestBody (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.handle_rule_engine_request_using_post_with_http_info(request_body, **kwargs)  # noqa: E501
        else:
            (data) = self.handle_rule_engine_request_using_post_with_http_info(request_body, **kwargs)  # noqa: E501
            return data

    def handle_rule_engine_request_using_post_with_http_info(self, request_body, **kwargs):  # noqa: E501
        """handleRuleEngineRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.handle_rule_engine_request_using_post_with_http_info(request_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str request_body: requestBody (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request_body' is set
        if ('request_body' not in params or
                params['request_body'] is None):
            raise ValueError("Missing the required parameter `request_body` when calling `handle_rule_engine_request_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in params:
            body_params = params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/rule-engine/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def handle_rule_engine_request_using_post1(self, entity_type, entity_id, timeout, request_body, **kwargs):  # noqa: E501
        """handleRuleEngineRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.handle_rule_engine_request_using_post1(entity_type, entity_id, timeout, request_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: entityType (required)
        :param str entity_id: entityId (required)
        :param int timeout: timeout (required)
        :param str request_body: requestBody (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.handle_rule_engine_request_using_post1_with_http_info(entity_type, entity_id, timeout, request_body, **kwargs)  # noqa: E501
        else:
            (data) = self.handle_rule_engine_request_using_post1_with_http_info(entity_type, entity_id, timeout, request_body, **kwargs)  # noqa: E501
            return data

    def handle_rule_engine_request_using_post1_with_http_info(self, entity_type, entity_id, timeout, request_body, **kwargs):  # noqa: E501
        """handleRuleEngineRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.handle_rule_engine_request_using_post1_with_http_info(entity_type, entity_id, timeout, request_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: entityType (required)
        :param str entity_id: entityId (required)
        :param int timeout: timeout (required)
        :param str request_body: requestBody (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['entity_type', 'entity_id', 'timeout', 'request_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'entity_type' is set
        if ('entity_type' not in params or
                params['entity_type'] is None):
            raise ValueError("Missing the required parameter `entity_type` when calling `handle_rule_engine_request_using_post1`")  # noqa: E501
        # verify the required parameter 'entity_id' is set
        if ('entity_id' not in params or
                params['entity_id'] is None):
            raise ValueError("Missing the required parameter `entity_id` when calling `handle_rule_engine_request_using_post1`")  # noqa: E501
        # verify the required parameter 'timeout' is set
        if ('timeout' not in params or
                params['timeout'] is None):
            raise ValueError("Missing the required parameter `timeout` when calling `handle_rule_engine_request_using_post1`")  # noqa: E501
        # verify the required parameter 'request_body' is set
        if ('request_body' not in params or
                params['request_body'] is None):
            raise ValueError("Missing the required parameter `request_body` when calling `handle_rule_engine_request_using_post1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'entity_type' in params:
            path_params['entityType'] = params['entity_type']  # noqa: E501
        if 'entity_id' in params:
            path_params['entityId'] = params['entity_id']  # noqa: E501
        if 'timeout' in params:
            path_params['timeout'] = params['timeout']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in params:
            body_params = params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/rule-engine/{entityType}/{entityId}/{timeout}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def handle_rule_engine_request_using_post2(self, entity_type, entity_id, request_body, **kwargs):  # noqa: E501
        """handleRuleEngineRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.handle_rule_engine_request_using_post2(entity_type, entity_id, request_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: entityType (required)
        :param str entity_id: entityId (required)
        :param str request_body: requestBody (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.handle_rule_engine_request_using_post2_with_http_info(entity_type, entity_id, request_body, **kwargs)  # noqa: E501
        else:
            (data) = self.handle_rule_engine_request_using_post2_with_http_info(entity_type, entity_id, request_body, **kwargs)  # noqa: E501
            return data

    def handle_rule_engine_request_using_post2_with_http_info(self, entity_type, entity_id, request_body, **kwargs):  # noqa: E501
        """handleRuleEngineRequest  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.handle_rule_engine_request_using_post2_with_http_info(entity_type, entity_id, request_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: entityType (required)
        :param str entity_id: entityId (required)
        :param str request_body: requestBody (required)
        :return: DeferredResultResponseEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['entity_type', 'entity_id', 'request_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'entity_type' is set
        if ('entity_type' not in params or
                params['entity_type'] is None):
            raise ValueError("Missing the required parameter `entity_type` when calling `handle_rule_engine_request_using_post2`")  # noqa: E501
        # verify the required parameter 'entity_id' is set
        if ('entity_id' not in params or
                params['entity_id'] is None):
            raise ValueError("Missing the required parameter `entity_id` when calling `handle_rule_engine_request_using_post2`")  # noqa: E501
        # verify the required parameter 'request_body' is set
        if ('request_body' not in params or
                params['request_body'] is None):
            raise ValueError("Missing the required parameter `request_body` when calling `handle_rule_engine_request_using_post2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'entity_type' in params:
            path_params['entityType'] = params['entity_type']  # noqa: E501
        if 'entity_id' in params:
            path_params['entityId'] = params['entity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in params:
            body_params = params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/rule-engine/{entityType}/{entityId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeferredResultResponseEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#

from tb_rest_client.rest_client_base import *

logger = getLogger(__name__)


class RestClientCE(RestClientBase):
    def __init__(self, base_url):
        super().__init__(base_url)

    """ Asset endpoints """

    def assign_asset_to_customer(self, customer_id: CustomerId, asset_id: AssetId):
        return self.asset_controller.assign_asset_to_customer_using_post(customer_id=customer_id, asset_id=asset_id)

    def unassign_asset_from_customer(self, asset_id: AssetId):
        return self.asset_controller.unassign_asset_from_customer_using_delete(asset_id=asset_id)

    def assign_asset_to_public_customer(self, asset_id: AssetId):
        return self.asset_controller.assign_asset_to_public_customer_using_post(asset_id=asset_id)

    """ Dashboard endpoints """

    def assign_dashboard_to_customer(self, customer_id: CustomerId, dashboard_id: DashboardId):
        return self.dashboard_controller.assign_dashboard_to_customer_using_post(customer_id=customer_id, dashboard_id=dashboard_id)

    def unassign_dashboard_from_customer(self, customer_id: CustomerId, dashboard_id: DashboardId):
        return self.dashboard_controller.unassign_dashboard_from_customer_using_delete(customer_id=customer_id, dashboard_id=dashboard_id)

    def update_dashboard_customers(self, dashboard_id: DashboardId, customerIds):
        return self.dashboard_controller.update_dashboard_customers_using_post(dashboard_id=dashboard_id, str_customer_ids=customerIds)

    def add_dashboard_customers(self, dashboard_id: DashboardId, customerIds):
        return self.dashboard_controller.add_dashboard_customers_using_post(dashboard_id=dashboard_id, str_customer_ids=customerIds)

    def remove_dashboard_customers(self, dashboard_id: DashboardId, customerIds):
        return self.dashboard_controller.remove_dashboard_customers_using_post(dashboard_id=dashboard_id, str_customer_ids=customerIds)

    def assign_dashboard_to_public_customer(self, dashboard_id: DashboardId):
        return self.dashboard_controller.assign_dashboard_to_public_customer_using_post(dashboard_id=dashboard_id)

    def unassign_dashboard_from_public_customer(self, dashboard_id: DashboardId):
        return self.dashboard_controller.unassign_dashboard_from_public_customer_using_delete(dashboard_id=dashboard_id)

    """ Device endpoints """

    def assign_device_to_customer(self, customer_id: CustomerId, device_id: DeviceId):
        return self.device_controller.assign_device_to_customer_using_post(customer_id=customer_id, device_id=device_id)

    def unassign_device_from_customer(self, customer_id: CustomerId, device_id: DeviceId):
        return self.device_controller.unassign_device_from_customer_using_delete(customer_id=customer_id, device_id=device_id)

    def assign_device_to_public_customer(self, device_id: DeviceId):
        return self.device_controller.assign_device_to_public_customer_using_post(device_id=device_id)

    """ Entity View endpoints """

    def assign_entity_view_to_customer(self, customer_id: CustomerId, entity_view_id: EntityViewId):
        return self.entity_view_controller.assign_entity_view_to_customer_using_post(customer_id=customer_id, entity_view_id=entity_view_id)

    def unassign_entity_view_from_customer(self, customer_id: CustomerId, entity_view_id: EntityViewId):
        return self.entity_view_controller.unassign_entity_view_from_customer_using_delete(customer_id=customer_id, entity_view_id=entity_view_id)

    def assign_entity_view_to_public_customer(self, entity_view_id: EntityViewId):
        return self.entity_view_controller.assign_entity_view_to_public_customer_using_post(entity_view_id=entity_view_id)



# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#

import pprint
import re  # noqa: F401

import six


class EntityRelation(object):
    """NOTE: This class is auto generated by the swagger code generator program.    
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_info': 'str',
        '_from': 'EntityId',
        'to': 'EntityId',
        'type': 'str',
        'type_group': 'str'
    }

    attribute_map = {
        'additional_info': 'additionalInfo',
        '_from': 'from',
        'to': 'to',
        'type': 'type',
        'type_group': 'typeGroup'
    }

    def __init__(self, additional_info=None, _from=None, to=None, type=None, type_group=None):  # noqa: E501
        """EntityRelation - a model defined in Swagger"""  # noqa: E501

        self._additional_info = None
        self.__from = None
        self._to = None
        self._type = None
        self._type_group = None
        self.discriminator = None

        if additional_info is not None:
            self.additional_info = additional_info
        if _from is not None:
            self._from = _from
        if to is not None:
            self.to = to
        if type is not None:
            self.type = type
        if type_group is not None:
            self.type_group = type_group

    @property
    def additional_info(self):
        """Gets the additional_info of this EntityRelation.  # noqa: E501


        :return: The additional_info of this EntityRelation.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this EntityRelation.


        :param additional_info: The additional_info of this EntityRelation.  # noqa: E501
        :type: str
        """

        self._additional_info = additional_info

    @property
    def _from(self):
        """Gets the _from of this EntityRelation.  # noqa: E501


        :return: The _from of this EntityRelation.  # noqa: E501
        :rtype: EntityId
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this EntityRelation.


        :param _from: The _from of this EntityRelation.  # noqa: E501
        :type: EntityId
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this EntityRelation.  # noqa: E501


        :return: The to of this EntityRelation.  # noqa: E501
        :rtype: EntityId
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this EntityRelation.


        :param to: The to of this EntityRelation.  # noqa: E501
        :type: EntityId
        """

        self._to = to

    @property
    def type(self):
        """Gets the type of this EntityRelation.  # noqa: E501


        :return: The type of this EntityRelation.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EntityRelation.


        :param type: The type of this EntityRelation.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def type_group(self):
        """Gets the type_group of this EntityRelation.  # noqa: E501


        :return: The type_group of this EntityRelation.  # noqa: E501
        :rtype: str
        """
        return self._type_group

    @type_group.setter
    def type_group(self, type_group):
        """Sets the type_group of this EntityRelation.


        :param type_group: The type_group of this EntityRelation.  # noqa: E501
        :type: str
        """
        allowed_values = ["COMMON", "ALARM", "DASHBOARD", "RULE_CHAIN", "RULE_NODE"]  # noqa: E501
        if type_group not in allowed_values:
            raise ValueError(
                "Invalid value for `type_group` ({0}), must be one of {1}"  # noqa: E501
                .format(type_group, allowed_values)
            )

        self._type_group = type_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EntityRelation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EntityRelation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
